#!/usr/bin/perl -w
# drawPie.pl - build a simple pie chart using modified GD::Pie.pm
use strict;
use lib qw(./);
use customPie;

if( @ARGV != 7 ){ die "specify an output filename" }

my( @name, @ratio ) = ();
my $filename = $ARGV[0];

## Run getPieData.sh

if( $ARGV[5] ne "summary") { 
  system ("/bin/bash","./getPieData.sh", $ARGV[6]);
} else {
  system ("/bin/bash","./getPieDataSummary.sh", $ARGV[6]);
}

open (INPUTDATA,"/tmp/inputData.txt") or die("Could not open inputData.txt");
chomp($filename);

while(<INPUTDATA>) {
my @parts = split "#", $_;
  push @name, " "; #add the names later
  push @ratio, $parts[1];
}

#while(<STDIN>){
#  my @parts = split "#", $_;
#  push @name, " "; #add the names later
#  push @ratio, $parts[1];
#}#while stdin

my $mygraph = GD::Graph::pie->new(600,600);
# colors of the pie slices
$mygraph->set( dclrs => [ "#A8A499","#685E3F","#6C7595","#D8E21F",
                          "#D19126","#B5B87D","#B7C8E2","#DFE3E1" ] );
# color of pie divisors
$mygraph->set( accentclr => '#0000ff');
$mygraph->set( '3d' =>'0');

my @togr = ( [@name], [@ratio] );

my $myimage = $mygraph->plot(\@togr) or die $mygraph->error;

open(IMG, "> $filename") or die $1;
  binmode IMG;
  print IMG $myimage->png;
close(IMG);


#### SECTION 2 ########

# compositePieIndicators.pl - build super pie graphics
#die "usage: compositePieIndicators.pl image_file " .
#    "vertices_file <main title> <sub title> data_file output_file"

my $pieImg = newFromPng GD::Image( $ARGV[0] );
my $white = $myimage->colorAllocate(255,255,255);
my @textLocs = ();


# draw the pie slices
open( POLYFILE, "$ARGV[1]" ) or die "can't open vertices file $ARGV[1]";
  while( my $polyLine = <POLYFILE> )
  {
    my (undef, @polyParts ) = split " ", $polyLine;
    my $poly = new GD::Polygon;

    my $textPos = 0;
    for ( @polyParts ){
      my( $px, $py ) = split ",";
      $poly->addPt( $px,$py );

      next unless $textPos == 0;
      push @textLocs, "$px, $py";
      $textPos = 1;

    }#for each polygon part

    $pieImg->filledPolygon( $poly, $white );
  }#polyCoords
close(POLYFILE);


## Section 2

my $whiteImg = new GD::Image(1200,1200);
my $secWhite = $whiteImg->colorAllocate(255,255,255);
my $black = $whiteImg->colorAllocate(0,0,0);
$whiteImg->copy( $pieImg, 200,200, 0,0, 600,600 );

# now build a squarish border to hide the drawing artifacts
my $circleImg = new GD::Image( 600,600 );
my $circlewhite = $circleImg->colorAllocate(255,255,255);
my $circleblack = $circleImg->colorAllocate(0,0,0);

$circleImg->filledArc(300,300, 580,580, 0,360,$black);
$circleImg->transparent($circleblack);

$whiteImg->copy($circleImg,200,200,0,0,600,600);

# make the pie radial divisor arms white
$whiteImg->fill(500,500,$secWhite);

# draw center white circle area for text
$whiteImg->filledArc( 500,500, 440,440, 0,360, $secWhite );

# draw black border around text area - with line arc
$whiteImg->setThickness(4);
$whiteImg->arc( 500,500, 425,425, 0,360, $black );

# main title
$whiteImg->stringFT( $black, '/usr/share/fonts/msttcorefonts/arial.ttf',
  45,0,350,470, "$ARGV[2]" );

# sub title
$whiteImg->stringFT( $black, '/usr/share/fonts/msttcorefonts/arial.ttf',
  32,0,370,560, "$ARGV[3]" );



## Section 3 

# draw the labels for the pie slices

open( DATAFILE, "$ARGV[4]" ) or die "can't open data file ";

  my $arrayPos = 0;
  while( my $line = <DATAFILE> )
  {
    #my( undef, undef, $text ) = split '#', $line;
    my( undef,$value, $text) = split '#', $line;
    my( $posx, $posy ) = split ',', $textLocs[$arrayPos];
    print "text $text $value at pos $textLocs[$arrayPos] \n";

    # the kludge text alignment zone
    $posx += 200;
    $posy += 200;
    my $ptSize = 14;

    if( $posx <= 500 ){
      if( $posy <= 500 ){
        # nudge left, up if upper left
        $posx -= 70;
        $posy -= 20;
      }else{
        # nudge left, down if upper left
        $posx -= 100;
        $posy += 20;
      }
    }else{
      if( $posy <= 500 ){
        # nudge left, down if upper right
        $posy -= 20;
        $posx += 10;
      }else{
        # nudge right, down if lower right
        $posy += 20 ;
        $posx += 25 ;
      }
    }#if left or right of image

    # nudge text down if right enough
    if( $posy > 600 ){ $posy += 10 }

    $whiteImg->stringFT( $black, '/usr/share/fonts/msttcorefonts/arial.ttf',
      $ptSize,0,$posx,$posy, "$text -" . " $value%" );

    $arrayPos++;
  }#while data file line
close(DATAFILE);

open( TILEOUT,"> $ARGV[0]") or die "can't write out file ";
  print TILEOUT $whiteImg->png;
close(TILEOUT);



